@@ -8,7 +8,6 @@ They will be deleted (set to None).
 """
 import numpy as np
 from pydicom import Dataset
-from pydicom.sequence import Sequence
 from pydicom.uid import ExplicitVRLittleEndian
 
 
@@ -22,12 +21,10 @@ def update_ds(ds: Dataset) -> Dataset:
     ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian
     ds.BurnedInAnnotation = 'NO'
     ds.PatientIdentityRemoved = 'YES'
-    text = ds.DeidentificationMethodCodeSequence
-    ds.DeidentificationMethod = f'{text}blackened pixels'
 
     ds_sq = Dataset()
     ds_sq.CodeValue = '113101'
-    ds.DeidentificationMethodCodeSequence = Sequence([ds_sq])
+    ds.DeidentificationMethodCodeSequence.append(ds_sq)
     return ds
 
 
@@ -36,7 +33,8 @@ def blacken_pixels(ds: Dataset) -> Dataset:
     Blacken pixel based on manufacturer, modality and image size.
     """
     try:
-        if 'PRIMARY' in ds.ImageType:
+        if 'PRIMARY' in (x for x in ds.ImageType):
+            print('here')
             # if ds.Modality == 'CT':
                 ## SECONDARY not included anymore!!
                 # if ds.Manufacturer == 'Agfa' \
@@ -50,7 +48,7 @@ def blacken_pixels(ds: Dataset) -> Dataset:
             if ds.Modality == 'US':
                 ## GE
                 if 'GE' in (x for x in ds.Manufacturer):
-                    print('here')
+
                     img = ds.pixel_array
                     if ds.PhotometricInterpretation == 'RGB':
                         try:
